@@ -63,9 +63,7 @@ class DotDensityPlotter(object):
         """
         Plots dots for all features in the source layer.
         """
-        feature = self.source_layer.GetNextFeature()
-
-        while feature:
+        for feature in self.source_layer: 
             self._plot(feature)
 
             feature = self.source_layer.GetNextFeature()
